# swarmauri_crypto_ecdh_es_a128kw

ECDH-ES+A128KW key wrapping provider for Swarmauri.

This plugin implements key wrapping and unwrapping using the
ECDH-ES key agreement scheme combined with AES Key Wrap using a
128-bit key. It exposes the `ECDHESA128KWCrypto` class which
conforms to the `ICrypto` contract.
